<?php

use DTElementor\Widgets\DTElementorWidgetBase;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

class Elementor_EmiCalculator extends DTElementorWidgetBase {

    public function get_name() {
        return 'dt-emicalculator';
    }

    public function get_title() {
        return esc_html__('Emi Calculator', 'dt-elementor');
    }

    public function get_icon() {
		return 'eicon-slider-push';
	}

	public function get_style_depends() {
		return array( 'rangeslider', 'dt.emicalculator' );
	}

	public function get_script_depends() {
		return array( 'rangeslider', 'dt.emicalculator' );
	}

    protected function register_controls() {

        $this->start_controls_section( 'dt_section_loanamount', array(
            'label' => esc_html__( 'Loan Amount', 'dt-elementor'),
        ) );

			$this->add_control(
				'loanamount_min_value',
				[
					'label' => esc_html__( 'Min Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 1000
				]
			);

			$this->add_control(
				'loanamount_max_value',
				[
					'label' => esc_html__( 'Max Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 10000
				]
			);

			$this->add_control(
				'loanamount_step_value',
				[
					'label' => esc_html__( 'Step Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 10
				]
			);

			$this->add_control(
				'loanamount_default_value',
				[
					'label' => esc_html__( 'Default Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 5000
				]
			);

		$this->end_controls_section();

        $this->start_controls_section( 'dt_section_tenure', array(
            'label' => esc_html__( 'Tenure ( Month )', 'dt-elementor'),
        ) );

			$this->add_control(
				'tenure_min_value',
				[
					'label' => esc_html__( 'Min Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 3
				]
			);

			$this->add_control(
				'tenure_max_value',
				[
					'label' => esc_html__( 'Max Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 50
				]
			);

			$this->add_control(
				'tenure_step_value',
				[
					'label' => esc_html__( 'Step Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 1
				]
			);

			$this->add_control(
				'tenure_default_value',
				[
					'label' => esc_html__( 'Default Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 12
				]
			);

		$this->end_controls_section();

        $this->start_controls_section( 'dt_section_interest_rate', array(
            'label' => esc_html__( 'Interest Rate (%)', 'dt-elementor'),
        ) );

			$this->add_control(
				'interest_rate_min_value',
				[
					'label' => esc_html__( 'Min Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 1
				]
			);

			$this->add_control(
				'interest_rate_max_value',
				[
					'label' => esc_html__( 'Max Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 20
				]
			);

			$this->add_control(
				'interest_rate_step_value',
				[
					'label' => esc_html__( 'Step Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 0.5
				]
			);

			$this->add_control(
				'interest_rate_default_value',
				[
					'label' => esc_html__( 'Default Value', 'dt-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 8
				]
			);

		$this->end_controls_section();

        $this->start_controls_section( 'dt_section_global_codes', array(
            'label' => esc_html__( 'Global Codes', 'dt-elementor'),
        ) );

			$this->add_control(
				'currency_code',
				[
					'label' => esc_html__( 'Currency Code', 'dt-elementor' ),
					'type' => Controls_Manager::SELECT2,
					'default' => 'USD',
					'options' => array (
						'AED' => 'AED', 
						'AFN' => 'AFN', 
						'ALL' => 'ALL', 
						'AMD' => 'AMD', 
						'ANG' => 'ANG', 
						'AOA' => 'AOA', 
						'ARS' => 'ARS', 
						'AUD' => 'AUD', 
						'AWG' => 'AWG', 
						'AZN' => 'AZN', 
						'BAM' => 'BAM', 
						'BBD' => 'BBD', 
						'BDT' => 'BDT', 
						'BGN' => 'BGN', 
						'BHD' => 'BHD', 
						'BIF' => 'BIF', 
						'BMD' => 'BMD', 
						'BND' => 'BND', 
						'BOB' => 'BOB', 
						'BOV' => 'BOV', 
						'BRL' => 'BRL', 
						'BSD' => 'BSD', 
						'BTN' => 'BTN', 
						'BWP' => 'BWP', 
						'BYN' => 'BYN', 
						'BZD' => 'BZD', 
						'CAD' => 'CAD', 
						'CDF' => 'CDF', 
						'CHE' => 'CHE', 
						'CHF' => 'CHF', 
						'CHW' => 'CHW', 
						'CLF' => 'CLF', 
						'CLP' => 'CLP', 
						'CNY' => 'CNY', 
						'COP' => 'COP', 
						'COU' => 'COU', 
						'CRC' => 'CRC', 
						'CUC' => 'CUC', 
						'CUP' => 'CUP', 
						'CVE' => 'CVE', 
						'CZK' => 'CZK', 
						'DJF' => 'DJF', 
						'DKK' => 'DKK', 
						'DOP' => 'DOP', 
						'DZD' => 'DZD', 
						'EGP' => 'EGP', 
						'ERN' => 'ERN', 
						'ETB' => 'ETB', 
						'EUR' => 'EUR', 
						'FJD' => 'FJD', 
						'FKP' => 'FKP', 
						'GBP' => 'GBP', 
						'GEL' => 'GEL', 
						'GHS' => 'GHS', 
						'GIP' => 'GIP', 
						'GMD' => 'GMD', 
						'GNF' => 'GNF', 
						'GTQ' => 'GTQ', 
						'GYD' => 'GYD', 
						'HKD' => 'HKD', 
						'HNL' => 'HNL', 
						'HRK' => 'HRK', 
						'HTG' => 'HTG', 
						'HUF' => 'HUF', 
						'IDR' => 'IDR', 
						'ILS' => 'ILS', 
						'INR' => 'INR', 
						'IQD' => 'IQD', 
						'IRR' => 'IRR', 
						'ISK' => 'ISK', 
						'JMD' => 'JMD', 
						'JOD' => 'JOD', 
						'JPY' => 'JPY', 
						'KES' => 'KES', 
						'KGS' => 'KGS', 
						'KHR' => 'KHR', 
						'KMF' => 'KMF', 
						'KPW' => 'KPW', 
						'KRW' => 'KRW', 
						'KWD' => 'KWD', 
						'KYD' => 'KYD', 
						'KZT' => 'KZT', 
						'LAK' => 'LAK', 
						'LBP' => 'LBP', 
						'LKR' => 'LKR', 
						'LRD' => 'LRD', 
						'LSL' => 'LSL', 
						'LYD' => 'LYD', 
						'MAD' => 'MAD', 
						'MDL' => 'MDL', 
						'MGA' => 'MGA', 
						'MKD' => 'MKD', 
						'MMK' => 'MMK', 
						'MNT' => 'MNT', 
						'MOP' => 'MOP', 
						'MRU' => 'MRU', 
						'MUR' => 'MUR', 
						'MVR' => 'MVR', 
						'MWK' => 'MWK', 
						'MXN' => 'MXN', 
						'MXV' => 'MXV', 
						'MYR' => 'MYR', 
						'MZN' => 'MZN', 
						'NAD' => 'NAD', 
						'NGN' => 'NGN', 
						'NIO' => 'NIO', 
						'NOK' => 'NOK', 
						'NPR' => 'NPR', 
						'NZD' => 'NZD', 
						'OMR' => 'OMR', 
						'PAB' => 'PAB', 
						'PEN' => 'PEN', 
						'PGK' => 'PGK', 
						'PHP' => 'PHP', 
						'PKR' => 'PKR', 
						'PLN' => 'PLN', 
						'PYG' => 'PYG', 
						'QAR' => 'QAR', 
						'RON' => 'RON', 
						'RSD' => 'RSD', 
						'RUB' => 'RUB', 
						'RWF' => 'RWF', 
						'SAR' => 'SAR', 
						'SBD' => 'SBD', 
						'SCR' => 'SCR', 
						'SDG' => 'SDG', 
						'SEK' => 'SEK', 
						'SGD' => 'SGD', 
						'SHP' => 'SHP', 
						'SLL' => 'SLL', 
						'SOS' => 'SOS', 
						'SRD' => 'SRD', 
						'SSP' => 'SSP', 
						'STN' => 'STN', 
						'SVC' => 'SVC', 
						'SYP' => 'SYP', 
						'SZL' => 'SZL', 
						'THB' => 'THB', 
						'TJS' => 'TJS', 
						'TMT' => 'TMT', 
						'TND' => 'TND', 
						'TOP' => 'TOP', 
						'TRY' => 'TRY', 
						'TTD' => 'TTD', 
						'TWD' => 'TWD', 
						'TZS' => 'TZS', 
						'UAH' => 'UAH', 
						'UGX' => 'UGX', 
						'USD' => 'USD', 
						'USN' => 'USN', 
						'UYI' => 'UYI', 
						'UYU' => 'UYU', 
						'UZS' => 'UZS', 
						'VEF' => 'VEF', 
						'VND' => 'VND', 
						'VUV' => 'VUV', 
						'WST' => 'WST', 
						'XAF' => 'XAF', 
						'XCD' => 'XCD', 
						'XDR' => 'XDR', 
						'XOF' => 'XOF', 
						'XPF' => 'XPF', 
						'XSU' => 'XSU', 
						'XUA' => 'XUA', 
						'YER' => 'YER', 
						'ZAR' => 'ZAR', 
						'ZMW' => 'ZMW', 
						'ZWL' => 'ZWL'														
					),
				]
			);

			$this->add_control(
				'language_code',
				[
					'label' => esc_html__( 'Language Code', 'dt-elementor' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'en',
					'options' => array (
						'ab' => 'Abkhazian', 
						'aa' => 'Afar', 
						'af' => 'Afrikaans', 
						'ak' => 'Akan', 
						'sq' => 'Albanian', 
						'am' => 'Amharic', 
						'ar' => 'Arabic', 
						'an' => 'Aragonese', 
						'hy' => 'Armenian', 
						'as' => 'Assamese', 
						'av' => 'Avaric', 
						'ae' => 'Avestan', 
						'ay' => 'Aymara', 
						'az' => 'Azerbaijani', 
						'bm' => 'Bambara', 
						'ba' => 'Bashkir', 
						'eu' => 'Basque', 
						'be' => 'Belarusian', 
						'bn' => 'Bengali (Bangla)', 
						'bh' => 'Bihari', 
						'bi' => 'Bislama', 
						'bs' => 'Bosnian', 
						'br' => 'Breton', 
						'bg' => 'Bulgarian', 
						'my' => 'Burmese', 
						'ca' => 'Catalan', 
						'ch' => 'Chamorro', 
						'ce' => 'Chechen', 
						'ny' => 'Chichewa, Chewa, Nyanja', 
						'zh' => 'Chinese', 
						'zh-Hans' => 'Chinese (Simplified)', 
						'zh-Hant' => 'Chinese (Traditional)', 
						'cv' => 'Chuvash', 
						'kw' => 'Cornish', 
						'co' => 'Corsican', 
						'cr' => 'Cree', 
						'hr' => 'Croatian', 
						'cs' => 'Czech', 
						'da' => 'Danish', 
						'dv' => 'Divehi, Dhivehi, Maldivian', 
						'nl' => 'Dutch', 
						'dz' => 'Dzongkha', 
						'en' => 'English', 
						'eo' => 'Esperanto', 
						'et' => 'Estonian', 
						'ee' => 'Ewe', 
						'fo' => 'Faroese', 
						'fj' => 'Fijian', 
						'fi' => 'Finnish', 
						'fr' => 'French', 
						'ff' => 'Fula, Fulah, Pulaar, Pular', 
						'gl' => 'Galician', 
						'gd' => 'Gaelic (Scottish)', 
						'gv' => 'Gaelic (Manx)', 
						'ka' => 'Georgian', 
						'de' => 'German', 
						'el' => 'Greek', 
						'kl' => 'Greenlandic', 
						'gn' => 'Guarani', 
						'gu' => 'Gujarati', 
						'ht' => 'Haitian Creole', 
						'ha' => 'Hausa', 
						'he' => 'Hebrew', 
						'hz' => 'Herero', 
						'hi' => 'Hindi', 
						'ho' => 'Hiri Motu', 
						'hu' => 'Hungarian', 
						'is' => 'Icelandic', 
						'io' => 'Ido', 
						'ig' => 'Igbo', 
						'id, in' => 'Indonesian', 
						'ia' => 'Interlingua', 
						'ie' => 'Interlingue', 
						'iu' => 'Inuktitut', 
						'ik' => 'Inupiak', 
						'ga' => 'Irish', 
						'it' => 'Italian', 
						'ja' => 'Japanese', 
						'jv' => 'Javanese', 
						'kl' => 'Kalaallisut, Greenlandic', 
						'kn' => 'Kannada', 
						'kr' => 'Kanuri', 
						'ks' => 'Kashmiri', 
						'kk' => 'Kazakh', 
						'km' => 'Khmer', 
						'ki' => 'Kikuyu', 
						'rw' => 'Kinyarwanda (Rwanda)', 
						'rn' => 'Kirundi', 
						'ky' => 'Kyrgyz', 
						'kv' => 'Komi', 
						'kg' => 'Kongo', 
						'ko' => 'Korean', 
						'ku' => 'Kurdish', 
						'kj' => 'Kwanyama', 
						'lo' => 'Lao', 
						'la' => 'Latin', 
						'lv' => 'Latvian (Lettish)', 
						'li' => 'Limburgish ( Limburger)', 
						'ln' => 'Lingala', 
						'lt' => 'Lithuanian', 
						'lu' => 'Luga-Katanga', 
						'lg' => 'Luganda, Ganda', 
						'lb' => 'Luxembourgish', 
						'gv' => 'Manx', 
						'mk' => 'Macedonian', 
						'mg' => 'Malagasy', 
						'ms' => 'Malay', 
						'ml' => 'Malayalam', 
						'mt' => 'Maltese', 
						'mi' => 'Maori', 
						'mr' => 'Marathi', 
						'mh' => 'Marshallese', 
						'mo' => 'Moldavian', 
						'mn' => 'Mongolian', 
						'na' => 'Nauru', 
						'nv' => 'Navajo', 
						'ng' => 'Ndonga', 
						'nd' => 'Northern Ndebele', 
						'ne' => 'Nepali', 
						'no' => 'Norwegian', 
						'nb' => 'Norwegian bokmÃ¥l', 
						'nn' => 'Norwegian nynorsk', 
						'ii' => 'Nuosu', 
						'oc' => 'Occitan', 
						'oj' => 'Ojibwe', 
						'cu' => 'Old Church Slavonic, Old Bulgarian', 
						'or' => 'Oriya', 
						'om' => 'Oromo (Afaan Oromo)', 
						'os' => 'Ossetian', 
						'pi' => 'PÄli', 
						'ps' => 'Pashto, Pushto', 
						'fa' => 'Persian (Farsi)', 
						'pl' => 'Polish', 
						'pt' => 'Portuguese', 
						'pa' => 'Punjabi (Eastern)', 
						'qu' => 'Quechua', 
						'rm' => 'Romansh', 
						'ro' => 'Romanian', 
						'ru' => 'Russian', 
						'se' => 'Sami', 
						'sm' => 'Samoan', 
						'sg' => 'Sango', 
						'sa' => 'Sanskrit', 
						'sr' => 'Serbian', 
						'sh' => 'Serbo-Croatian', 
						'st' => 'Sesotho', 
						'tn' => 'Setswana', 
						'sn' => 'Shona', 
						'ii' => 'Sichuan Yi', 
						'sd' => 'Sindhi', 
						'si' => 'Sinhalese', 
						'ss' => 'Siswati', 
						'sk' => 'Slovak', 
						'sl' => 'Slovenian', 
						'so' => 'Somali', 
						'nr' => 'Southern Ndebele', 
						'es' => 'Spanish', 
						'su' => 'Sundanese', 
						'sw' => 'Swahili (Kiswahili)', 
						'ss' => 'Swati', 
						'sv' => 'Swedish', 
						'tl' => 'Tagalog', 
						'ty' => 'Tahitian', 
						'tg' => 'Tajik', 
						'ta' => 'Tamil', 
						'tt' => 'Tatar', 
						'te' => 'Telugu', 
						'th' => 'Thai', 
						'bo' => 'Tibetan', 
						'ti' => 'Tigrinya', 
						'to' => 'Tonga', 
						'ts' => 'Tsonga', 
						'tr' => 'Turkish', 
						'tk' => 'Turkmen', 
						'tw' => 'Twi', 
						'ug' => 'Uyghur', 
						'uk' => 'Ukrainian', 
						'ur' => 'Urdu', 
						'uz' => 'Uzbek', 
						've' => 'Venda', 
						'vi' => 'Vietnamese', 
						'vo' => 'VolapÃ¼k', 
						'wa' => 'Wallon', 
						'cy' => 'Welsh', 
						'wo' => 'Wolof', 
						'fy' => 'Western Frisian', 
						'xh' => 'Xhosa', 
						'yi, ji' => 'Yiddish', 
						'yo' => 'Yoruba', 
						'za' => 'Zhuang, Chuang', 
						'zu' => 'Zulu'							 
					),
				]
			);

			$this->add_control(
				'country_code',
				[
					'label' => esc_html__( 'Country Code', 'dt-elementor' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'US',
					'options' => array (
						'AF' => 'AFGHANISTAN', 
						'AL' => 'ALBANIA', 
						'DZ' => 'ALGERIA', 
						'AS' => 'AMERICAN SAMOA', 
						'AD' => 'ANDORRA', 
						'AO' => 'ANGOLA', 
						'AQ' => 'ANTARCTICA', 
						'AG' => 'ANTIGUA AND BARBUDA', 
						'AR' => 'ARGENTINA', 
						'AM' => 'ARMENIA', 
						'AW' => 'ARUBA', 
						'AU' => 'AUSTRALIA', 
						'AT' => 'AUSTRIA', 
						'AZ' => 'AZERBAIJAN', 
						'BS' => 'BAHAMAS', 
						'BH' => 'BAHRAIN', 
						'BD' => 'BANGLADESH', 
						'BB' => 'BARBADOS', 
						'BY' => 'BELARUS', 
						'BE' => 'BELGIUM', 
						'BZ' => 'BELIZE', 
						'BJ' => 'BENIN', 
						'BM' => 'BERMUDA', 
						'BT' => 'BHUTAN', 
						'BO' => 'BOLIVIA', 
						'BA' => 'BOSNIA AND HERZEGOVINA', 
						'BW' => 'BOTSWANA', 
						'BV' => 'BOUVET ISLAND', 
						'BR' => 'BRAZIL', 
						'IO' => 'BRITISH INDIAN OCEAN TERRITORY', 
						'BN' => 'BRUNEI DARUSSALAM', 
						'BG' => 'BULGARIA', 
						'BF' => 'BURKINA FASO', 
						'BI' => 'BURUNDI', 
						'KH' => 'CAMBODIA', 
						'CM' => 'CAMEROON', 
						'CA' => 'CANADA', 
						'CV' => 'CAPE VERDE', 
						'KY' => 'CAYMAN ISLANDS', 
						'CF' => 'CENTRAL AFRICAN REPUBLIC', 
						'TD' => 'CHAD', 
						'CL' => 'CHILE', 
						'CN' => 'CHINA', 
						'CX' => 'CHRISTMAS ISLAND', 
						'CC' => 'COCOS (KEELING) ISLANDS', 
						'CO' => 'COLOMBIA', 
						'KM' => 'COMOROS', 
						'CG' => 'CONGO', 
						'CD' => 'CONGO, THE DEMOCRATIC REPUBLIC OF THE', 
						'CK' => 'COOK ISLANDS', 
						'CR' => 'COSTA RICA', 
						'CI' => 'CÃTE D\'IVOIRE', 
						'HR' => 'CROATIA', 
						'CU' => 'CUBA', 
						'CY' => 'CYPRUS', 
						'CZ' => 'CZECH REPUBLIC', 
						'DK' => 'DENMARK', 
						'DJ' => 'DJIBOUTI', 
						'DM' => 'DOMINICA', 
						'DO' => 'DOMINICAN REPUBLIC', 
						'EC' => 'ECUADOR', 
						'EG' => 'EGYPT', 
						'SV' => 'EL SALVADOR', 
						'GQ' => 'EQUATORIAL GUINEA', 
						'ER' => 'ERITREA', 
						'EE' => 'ESTONIA', 
						'ET' => 'ETHIOPIA', 
						'FK' => 'FALKLAND ISLANDS (MALVINAS)', 
						'FO' => 'FAROE ISLANDS', 
						'FJ' => 'FIJI', 
						'FI' => 'FINLAND', 
						'FR' => 'FRANCE', 
						'GF' => 'FRENCH GUIANA', 
						'PF' => 'FRENCH POLYNESIA', 
						'TF' => 'FRENCH SOUTHERN TERRITORIES', 
						'GA' => 'GABON', 
						'GM' => 'GAMBIA', 
						'GE' => 'GEORGIA', 
						'DE' => 'GERMANY', 
						'GH' => 'GHANA', 
						'GI' => 'GIBRALTAR', 
						'GR' => 'GREECE', 
						'GL' => 'GREENLAND', 
						'GD' => 'GRENADA', 
						'GP' => 'GUADELOUPE', 
						'GU' => 'GUAM', 
						'GT' => 'GUATEMALA', 
						'GN' => 'GUINEA', 
						'GW' => 'GUINEA-BISSAU', 
						'GY' => 'GUYANA', 
						'HT' => 'HAITI', 
						'HM' => 'HEARD ISLAND AND MCDONALD ISLANDS', 
						'HN' => 'HONDURAS', 
						'HK' => 'HONG KONG', 
						'HU' => 'HUNGARY', 
						'IS' => 'ICELAND', 
						'IN' => 'INDIA', 
						'ID' => 'INDONESIA', 
						'IR' => 'IRAN, ISLAMIC REPUBLIC OF', 
						'IQ' => 'IRAQ', 
						'IE' => 'IRELAND', 
						'IL' => 'ISRAEL', 
						'IT' => 'ITALY', 
						'JM' => 'JAMAICA', 
						'JP' => 'JAPAN', 
						'JO' => 'JORDAN', 
						'KZ' => 'KAZAKHSTAN', 
						'KE' => 'KENYA', 
						'KI' => 'KIRIBATI', 
						'KP' => 'KOREA, DEMOCRATIC PEOPLE\'S REPUBLIC OF', 
						'KR' => 'KOREA, REPUBLIC OF', 
						'KW' => 'KUWAIT', 
						'KG' => 'KYRGYZSTAN', 
						'LA' => 'LAO PEOPLE\'S DEMOCRATIC REPUBLIC
							(LAOS)', 
						'LV' => 'LATVIA', 
						'LB' => 'LEBANON', 
						'LS' => 'LESOTHO', 
						'LR' => 'LIBERIA', 
						'LY' => 'LIBYAN ARAB JAMAHIRIYA', 
						'LI' => 'LIECHTENSTEIN', 
						'LT' => 'LITHUANIA', 
						'LU' => 'LUXEMBOURG', 
						'MO' => 'MACAO', 
						'MK' => 'MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF', 
						'MG' => 'MADAGASCAR', 
						'MW' => 'MALAWI', 
						'MY' => 'MALAYSIA', 
						'MV' => 'MALDIVES', 
						'ML' => 'MALI', 
						'MT' => 'MALTA', 
						'MH' => 'MARSHALL ISLANDS', 
						'MQ' => 'MARTINIQUE', 
						'MR' => 'MAURITANIA', 
						'MU' => 'MAURITIUS', 
						'YT' => 'MAYOTTE', 
						'MX' => 'MEXICO', 
						'FM' => 'MICRONESIA, FEDERATED STATES OF', 
						'MD' => 'MOLDOVA, REPUBLIC OF', 
						'MC' => 'MONACO', 
						'MN' => 'MONGOLIA', 
						'ME' => 'MONTENEGRO', 
						'MS' => 'MONTSERRAT', 
						'MA' => 'MOROCCO', 
						'MZ' => 'MOZAMBIQUE', 
						'MM' => 'MYANMAR', 
						'NA' => 'NAMIBIA', 
						'NR' => 'NAURU', 
						'NP' => 'NEPAL', 
						'NL' => 'NETHERLANDS', 
						'AN' => 'NETHERLANDS ANTILLES', 
						'NC' => 'NEW CALEDONIA', 
						'NZ' => 'NEW ZEALAND', 
						'NI' => 'NICARAGUA', 
						'NE' => 'NIGER', 
						'NG' => 'NIGERIA', 
						'NU' => 'NIUE', 
						'NF' => 'NORFOLK ISLAND', 
						'MP' => 'NORTHERN MARIANA ISLANDS', 
						'NO' => 'NORWAY', 
						'OM' => 'OMAN', 
						'PK' => 'PAKISTAN', 
						'PW' => 'PALAU', 
						'PS' => 'PALESTINIAN TERRITORY, OCCUPIED', 
						'PA' => 'PANAMA', 
						'PG' => 'PAPUA NEW GUINEA', 
						'PY' => 'PARAGUAY', 
						'PE' => 'PERU', 
						'PH' => 'PHILIPPINES', 
						'PN' => 'PITCAIRN', 
						'PL' => 'POLAND', 
						'PT' => 'PORTUGAL', 
						'PR' => 'PUERTO RICO', 
						'QA' => 'QATAR', 
						'RE' => 'RÃUNION', 
						'RO' => 'ROMANIA', 
						'RU' => 'RUSSIAN FEDERATION', 
						'RW' => 'RWANDA', 
						'SH' => 'SAINT HELENA', 
						'KN' => 'SAINT KITTS AND NEVIS', 
						'LC' => 'SAINT LUCIA', 
						'PM' => 'SAINT PIERRE AND MIQUELON', 
						'VC' => 'SAINT VINCENT AND THE GRENADINES', 
						'WS' => 'SAMOA', 
						'SM' => 'SAN MARINO', 
						'ST' => 'SAO TOME AND PRINCIPE', 
						'SA' => 'SAUDI ARABIA', 
						'SN' => 'SENEGAL', 
						'RS' => 'SERBIA', 
						'SC' => 'SEYCHELLES', 
						'SL' => 'SIERRA LEONE', 
						'SG' => 'SINGAPORE', 
						'SK' => 'SLOVAKIA', 
						'SI' => 'SLOVENIA', 
						'SB' => 'SOLOMON ISLANDS', 
						'SO' => 'SOMALIA', 
						'ZA' => 'SOUTH AFRICA', 
						'GS' => 'SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS', 
						'ES' => 'SPAIN', 
						'LK' => 'SRI LANKA', 
						'SD' => 'SUDAN', 
						'SR' => 'SURINAME', 
						'SJ' => 'SVALBARD AND JAN MAYEN', 
						'SZ' => 'SWAZILAND', 
						'SE' => 'SWEDEN', 
						'CH' => 'SWITZERLAND', 
						'SY' => 'SYRIAN ARAB REPUBLIC', 
						'TW' => 'TAIWAN', 
						'TJ' => 'TAJIKISTAN', 
						'TZ' => 'TANZANIA, UNITED REPUBLIC OF', 
						'TH' => 'THAILAND', 
						'TL' => 'TIMOR-LESTE', 
						'TG' => 'TOGO', 
						'TK' => 'TOKELAU', 
						'TO' => 'TONGA', 
						'TT' => 'TRINIDAD AND TOBAGO', 
						'TN' => 'TUNISIA', 
						'TR' => 'TURKEY', 
						'TM' => 'TURKMENISTAN', 
						'TC' => 'TURKS AND CAICOS ISLANDS', 
						'TV' => 'TUVALU', 
						'UG' => 'UGANDA', 
						'UA' => 'UKRAINE', 
						'AE' => 'UNITED ARAB EMIRATES', 
						'GB' => 'UNITED KINGDOM', 
						'US' => 'UNITED STATES', 
						'UM' => 'UNITED STATES MINOR OUTLYING ISLANDS', 
						'UY' => 'URUGUAY', 
						'UZ' => 'UZBEKISTAN', 
						'VU' => 'VANUATU', 
						'VE' => 'VENEZUELA', 
						'VN' => 'VIET NAM', 
						'VG' => 'VIRGIN ISLANDS, BRITISH', 
						'VI' => 'VIRGIN ISLANDS, U.S.', 
						'WF' => 'WALLIS AND FUTUNA', 
						'EH' => 'WESTERN SAHARA', 
						'YE' => 'YEMEN', 
						'ZM' => 'ZAMBIA', 
						'ZW' => 'ZIMBABWE'
					),
				]
			);


		$this->end_controls_section();
		
    }

    protected function render() {
		
		$settings = $this->get_settings();
		extract($settings);
		
		$output = '<div class="dt-sc-emicalculator-wrapper" data-currency-code="'.esc_attr($currency_code).'" data-language-code="'.esc_attr($language_code).'" data-country-code="'.esc_attr($country_code).'">';
			$output .= '<div class="dt-sc-emicalculator-inner">';

				$output .= '<div class="dt-sc-emicalculator-range-holder dt-sc-emicalculator-loanamount-range">';

					$output .= '<label>'.esc_html__('Loan Amount', 'dt-elementor').' <span class="dt-sc-currency-symbol"></span></label>';
					$output .= '<input type="text" class="loanamount" value="'.esc_attr($loanamount_default_value).'">';
					$output .= '<input type="range" id="loanamount" min="'.esc_attr($loanamount_min_value).'" max="'.esc_attr($loanamount_max_value).'" step="'.esc_attr($loanamount_step_value).'" value="'.esc_attr($loanamount_default_value).'" data-orientation="horizontal" >';
					
					$output .= '<div class="dt-sc-emicalculator-range">';
						$output .= '<div class="dt-sc-emicalculator-range-min">'.esc_html($loanamount_min_value).'</div>';
						$output .= '<div class="dt-sc-emicalculator-range-max">'.esc_html($loanamount_max_value).'</div>';
					$output .= '</div>';

				$output .= '</div>';

				$output .= '<div class="dt-sc-emicalculator-range-holder dt-sc-emicalculator-tenure-range">';

					$output .= '<label>'.esc_html__('Tenure', 'dt-elementor').' <span class="dt-sc-currency-symbol">(Month)</span></label>';
					$output .= '<input type="text" class="tenturemonths" value="'.esc_attr($tenure_default_value).'">';
					$output .= '<input type="range" id="tenturemonths" min="'.esc_attr($tenure_min_value).'" max="'.esc_attr($tenure_max_value).'" step="'.esc_attr($tenure_step_value).'" value="'.esc_attr($tenure_default_value).'" data-orientation="horizontal" >';
					
					$output .= '<div class="dt-sc-emicalculator-range">';
						$output .= '<div class="dt-sc-emicalculator-range-min">'.esc_html($tenure_min_value).'</div>';
						$output .= '<div class="dt-sc-emicalculator-range-max">'.esc_html($tenure_max_value).'</div>';
					$output .= '</div>';

				$output .= '</div>';

				$output .= '<div class="dt-sc-emicalculator-range-holder dt-sc-emicalculator-interest-rate-range">';

					$output .= '<label>'.esc_html__('Interest Rate', 'dt-elementor').' <span class="dt-sc-currency-symbol">(%)</span></label>';
					$output .= '<input type="text" class="interestrate" value="'.esc_attr($interest_rate_default_value).'">';
					$output .= '<input type="range" id="interestrate" min="'.esc_attr($interest_rate_min_value).'" max="'.esc_attr($interest_rate_max_value).'" step="'.esc_attr($interest_rate_step_value).'" value="'.esc_attr($interest_rate_default_value).'" data-orientation="horizontal" >';
					
					$output .= '<div class="dt-sc-emicalculator-range">';
						$output .= '<div class="dt-sc-emicalculator-range-min">'.esc_html($interest_rate_min_value).'</div>';
						$output .= '<div class="dt-sc-emicalculator-range-max">'.esc_html($interest_rate_max_value).'</div>';
					$output .= '</div>';

				$output .= '</div>';

				$output .= '<div class="dt-sc-emicalculator-result-holder">';

					$output .= '<div class="dt-sc-emicalculator-result dt-sc-emicalculator-monthlyemi-result">';
						$output .= esc_html__('Monthly EMI', 'dt-elementor');
						$output .= '<div class="monthly_emi"></div>';
					$output .= '</div>';

					$output .= '<div class="dt-sc-emicalculator-result dt-sc-emicalculator-totalinterestpayable-result">';
						$output .= esc_html__('Total Interest', 'dt-elementor');
						$output .= '<div class="total_interest_payable"></div>';
					$output .= '</div>';

					$output .= '<div class="dt-sc-emicalculator-result dt-sc-emicalculator-totalamountpayable-result">';
						$output .= esc_html__('Total Amount', 'dt-elementor');
						$output .= '<div class="total_amount_payable"></div>';
					$output .= '</div>';

				$output .= '</div>';
				
			$output .= '</div>';

		$output .= '</div>';

		echo $output;

	}

    protected function _content_template() {
	}

}