<?php

use DTElementor\Widgets\DTElementorWidgetBase;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;


class Elementor_CustomIcon extends DTElementorWidgetBase {

    public function get_name() {
        return 'dt-customicon';
    }

    public function get_title() {
        return esc_html__('Custom Icon', 'dt-elementor');
    }

    public function get_icon() {
		return 'eicon-slider-push';
	}

	public function get_style_depends() {
		return array( 'dt.customiconswitch' );
	}

	public function get_script_depends() {
		return array( 'dt.customiconswitch' );
	}

    protected function register_controls() {

        $this->start_controls_section( 'dt_section_general', array(
            'label' => esc_html__( 'General', 'dt-elementor'),
        ) );

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'dt-elementor' ),
					'type' => Controls_Manager::TEXT
				]
			);

			$this->add_control(
				'selected_icon',
				[
					'label' => esc_html__( 'Icon', 'dt-elementor' ),
					'type' => Controls_Manager::ICONS,
					'fa4compatibility' => 'icon',
					'default' => [
						'value' => 'fas fa-star',
						'library' => 'fa-solid',
					],
				]
			);

			$this->add_control(
				'icon_align_right',
				[
					'label' => esc_html__( 'Align Icon Right', 'dt-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'default' => 'no',
					'label_on' => esc_html__( 'Show', 'dt-elementor' ),
					'label_off' => esc_html__( 'Hide', 'dt-elementor' ),
				]
			);

			$this->add_control(
				'trigger_image_switch',
				[
					'label' => esc_html__( 'Trigger Image Switch', 'dt-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'default' => 'no',
					'label_on' => esc_html__( 'Show', 'dt-elementor' ),
					'label_off' => esc_html__( 'Hide', 'dt-elementor' ),
				]
			);

 			$this->add_control(
				'switch_image',
				[
					'label' => esc_html__( 'Choose Switch Image', 'dt-elementor' ),
					'type' => Controls_Manager::MEDIA,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
					'condition' => [
						'trigger_image_switch' => 'yes',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Image_Size::get_type(),
				[
					'name' => 'thumbnail',
					'default' => 'full',
					'separator' => 'none',
					'condition' => [
						'trigger_image_switch' => 'yes',
					],
				]
			);

		$this->end_controls_section();
		
    }

    protected function render() {
		
		$settings = $this->get_settings();
		extract($settings);

		$additional_class = '';
		$image_switch_url = '';
		if($trigger_image_switch == 'yes') {
			$additional_class .= 'dt-sc-customicon-image-switch';
			$image_switch_url = $switch_image['url'];
		}
		if($icon_align_right == 'yes') {
			$additional_class .= ' dt-sc-customicon-icon-alignright';
		}

		$output = '<div class="dt-sc-customicon-wrapper '.esc_attr($additional_class).'">';
			$output .= '<div class="dt-sc-customicon-inner" data-image="'.esc_attr($image_switch_url).'">';
				$output .= '<div class="dt-sc-customicon-icon-wrapper">';
					if($selected_icon['library'] == 'svg') {
						$output .= '<img src="'.esc_attr($selected_icon['value']['url']).'" alt="'.esc_attr($title).'">';
					} else {
						$output .= '<span class="'.esc_attr($selected_icon['value']).'"></span>';
					}
				$output .= '</div>';
				if(!empty($title)) {
					$output .= '<h4 class="dt-sc-customicon-title">'.esc_attr($title).'</h4>';
				}
			$output .= '</div>';
		$output .= '</div>';

		echo $output;

	}

    protected function _content_template() {
    }
}